@@ -35,11 +35,13 @@ def main():
         # Shift the purple node back and forth
         lw.back_and_forth()
 
-        # Set a few color groups
+        # Set a few color groups and rotate them
         frame.set_node_colors_by_name(
             ['red', 'orange', 'yellow', 'green', 'blue', 'indigo', 'violet']
         )
         lw.write_frame(frame)
+        time.sleep(1)
+        lw.rotate()
 
         # Go Crazy
         lw.random()
